@@ -155,6 +155,10 @@ class AlreadyScanningException(Exception):
     pass
 
 
+class ControllerNotReady(Exception):
+    pass
+
+
 class MainController:
     RESPONDING = 'RESPONDING'
     NOT_RESPONDING = 'NOT_RESPONDING'
@@ -214,7 +218,16 @@ class MainController:
         if self._scanCommand:
             return self._scanCommand.to_dict()
 
+    def _check_ready(self):
+        status = self.get_connection_status()
+        logger.info('Phootonics controller status: {}'.format(status))
+        if status != MainController.RESPONDING:
+            raise ControllerNotReady
+        if not self.is_ready_to_action() == 'READY':
+            raise ControllerNotReady
+
     def start_scan(self, wavelengths=None, positions=None):
+        self._check_ready()
         if self._scanCommandThread:
             if self._scanCommandThread.is_alive():
                 raise AlreadyScanningException
